Struct seahash::State [−][src]
pub struct State { /* fields omitted */ }Expand description
A SeaHash state.
Implementations
Create a new state vector with some initial values.
Hash a buffer with some seed.
Remove the most recently written 64-bit integer from the state.
Given the value of the most recently written u64 last, remove it from the state.